@@ -12,6 +12,7 @@
 /*--------------------------------------------------------------------------*/
 #include "JIMS.h"
 #include "OptionsHelper.h"
+#include "gw_helper.h"
 #include "ScilabObjects.h"
 #include "stack-c.h"
 #include "api_scilab.h"
@@ -21,7 +22,6 @@
 /*--------------------------------------------------------------------------*/
 int sci_jenableTrace(char *fname)
 {
-    SciErr err;
     char *filename = NULL;
     char *errmsg = NULL;
 
