@@ -71,7 +71,7 @@ int compareStrToMlistType(char *str, int *mlist)
         return 0;
     }
 
-    mlist_type = (char*)MALLOC(sizeof(char*) * rows * cols);
+    mlist_type = (char**)MALLOC(sizeof(char*) * (rows * cols));
     for (; i < rows * cols; i++)
     {
         mlist_type[i] = (char*)MALLOC(sizeof(char) * (lengths[i] + 1));
