@@ -14,7 +14,7 @@
 #include "ScilabJavaObject.hxx"
 #include "ScilabJavaObjectBis.hxx"
 /*--------------------------------------------------------------------------*/
-#define SCILABJAVAOBJECT "ScilabObjects/ScilabJavaObject"
+#define SCILABJAVAOBJECT "org/scilab/forge/jims/ScilabJavaObject"
 /*--------------------------------------------------------------------------*/
 void ScilabJavaObjectBis::releaseDirectBuffer(JavaVM * jvm_, void** ref, int* javaID, int len)
 {
